using System; 
using System.Diagnostics;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Data.SqlClient;

namespace Akadia.DataView 
{
	public class FilterOrder : System.Windows.Forms.Form 
	{
		internal System.Windows.Forms.TabControl TabControl1;
		internal System.Windows.Forms.TabPage TabPage1;
		internal System.Windows.Forms.TextBox txtFilter;
		internal System.Windows.Forms.Label Label1;
		internal System.Windows.Forms.TabPage TabPage2;
		internal System.Windows.Forms.TextBox txtGeneralFilter;
		internal System.Windows.Forms.Button btnGeneralFilter;
		internal System.Windows.Forms.Label Label3;
		internal System.Windows.Forms.TabPage TabPage4;
		internal System.Windows.Forms.ComboBox cmbFields;
		internal System.Windows.Forms.TextBox txtFilterColumn;
		internal System.Windows.Forms.Label Label4;
		internal System.Windows.Forms.TabPage TabPage3;
		internal System.Windows.Forms.RadioButton rbDsc;
		internal System.Windows.Forms.Button btnSort;
		internal System.Windows.Forms.RadioButton rbAsc;
		internal System.Windows.Forms.Label Label2;
		internal System.Windows.Forms.ComboBox cmbSortArg;
		internal System.Windows.Forms.DataGrid DataGrid;
		internal System.Windows.Forms.Button btnQuery;
		internal System.Windows.Forms.Button btnFilterTitle;
		internal System.Windows.Forms.Button btnFilteronColumn;
		internal System.Windows.Forms.Label label5;
		private System.ComponentModel.Container components = null;

		private SqlConnection cn; 
		private SqlCommand cmd; 
		private SqlDataAdapter da;
		private DataSet ds; 
     
		public FilterOrder() 
		{
			try 
			{
				InitializeComponent();

				// Initializing
				cn = new SqlConnection("server=xeon;database=northwind;uid=sa;pwd=manager");
				cmd = new SqlCommand("SELECT * FROM orders",cn);
				da = new SqlDataAdapter(cmd);
				ds = new DataSet();

				// Load initial Data
				RetrieveData();
			}
			catch (Exception ex) 
			{
				MessageBox.Show(ex.ToString());
				Console.WriteLine();
			}
		}

		// Retrieve Orders from the DB into the DataGrid
		private void RetrieveData() 
		{
			try
			{
				da.Fill(ds,"Orders");
				DataGrid.DataSource = ds.Tables[0];

				// Fill Combobx with Column Names
				FillSortCriteria();
			}
			catch (Exception ex) 
			{
				Debug.WriteLine(ex.ToString());
				MessageBox.Show(ex.ToString());
			}
		}

		// Fill Combobx with Column Names
		private void FillSortCriteria() 
		{
			try 
			{
				// IF Combobox are already filled return ...
				if (cmbSortArg.Items.Count > 0) 
				{
					return;
				}
				// ... else fill Comobox with Column Names
				foreach (DataColumn dc in ds.Tables[0].Columns) 
				{
					cmbSortArg.Items.Add(dc.Caption);  // Sort Combobox
					cmbFields.Items.Add(dc.Caption);   // Filter on Column Combobox
				}
			} 
			catch (Exception ex) 
			{
				MessageBox.Show(ex.ToString());
				Console.WriteLine();
			}
		}

		// Setup the expression used to filter the rows which 
		// are viewed by the DefaultView
		private void SetFilter(string strFilterExpression) 
		{
			try 
			{
				// Apply Filter Expression
				ds.Tables[0].DefaultView.RowFilter = strFilterExpression;

				// Gets the number of records in the DataView after
				// RowFilter and RowStateFilter have been applied.
				if (ds.Tables[0].DefaultView.Count > 0) 
				{
					DataGrid.DataSource = ds.Tables[0].DefaultView;
				}
				else 
				{
					MessageBox.Show("Filter criteria does not meet criteria");
				}
			}
			catch (Exception ex) 
			{
				MessageBox.Show(ex.ToString());
				Console.WriteLine();
			}
		}

		// Remove any existing Filter and ResultSet from a previous query
		private void btnQuery_Click(object sender, System.EventArgs e) 
		{
			try 
			{
				// Clear DataSet
				ds.Clear();          

				// Clear Filter
				ds.Tables[0].DefaultView.RowFilter = "";

				// Re-Retrieve Data
				RetrieveData();
			}
			catch (Exception ex) 
			{
				MessageBox.Show(ex.ToString());
				Console.WriteLine();
			}
		}

		// Sets the sort column or columns, and sort order for the DataView
		private void btnSort_Click(object sender, System.EventArgs e) 
		{
			try 
			{
				string strSort;

				// IF Radiobox "Ascending" is checked, then
				// sort ascending ...
				if (rbAsc.Checked) 
				{
					strSort = cmbSortArg.Text + " ASC";       // Note space after "
				}
				// ... else descending
				else 
				{
					strSort = cmbSortArg.Text + " DESC";     // Note space after "
				}

				// Apply Sort Criteria to the DataView
				ds.Tables[0].DefaultView.Sort = strSort;
				DataGrid.DataSource = ds.Tables[0].DefaultView;
			}
			catch (Exception ex) 
			{
				MessageBox.Show(ex.ToString());
				Console.WriteLine();
			}
            
		}

		// Setup specific Filter: "CutomerID LIKE 'xxx'"
		private void btnFilterTitle_Click(object sender, System.EventArgs e) 
		{
			try 
			{
				SetFilter("CustomerID like '" + txtFilter.Text + "'");
			}
			catch (Exception ex) 
			{
				MessageBox.Show(ex.ToString());
				Console.WriteLine();
			}
		}

		// Setup the general Filter entered by the User
		private void btnGeneralFilter_Click(object sender, System.EventArgs e) 
		{
			try 
			{
				SetFilter(txtGeneralFilter.Text);
			}
			catch (Exception ex) 
			{
				MessageBox.Show(ex.ToString());
				Console.WriteLine();
			}

		}

		// Setup the Column Filter entered by the User
		private void btnFilteronColumn_Click(object sender, System.EventArgs e) 
		{
			try 
			{
				SetFilter(cmbFields.Text + " " + txtFilterColumn.Text);
			}
			catch (Exception ex) 
			{
				MessageBox.Show(ex.ToString());
				Console.WriteLine();
			}
		}

		protected override void Dispose( bool disposing ) 
		{
			if( disposing ) 
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent() 
		{
			this.TabControl1 = new System.Windows.Forms.TabControl();
			this.TabPage1 = new System.Windows.Forms.TabPage();
			this.txtFilter = new System.Windows.Forms.TextBox();
			this.btnFilterTitle = new System.Windows.Forms.Button();
			this.Label1 = new System.Windows.Forms.Label();
			this.TabPage4 = new System.Windows.Forms.TabPage();
			this.label5 = new System.Windows.Forms.Label();
			this.cmbFields = new System.Windows.Forms.ComboBox();
			this.txtFilterColumn = new System.Windows.Forms.TextBox();
			this.btnFilteronColumn = new System.Windows.Forms.Button();
			this.Label4 = new System.Windows.Forms.Label();
			this.TabPage2 = new System.Windows.Forms.TabPage();
			this.txtGeneralFilter = new System.Windows.Forms.TextBox();
			this.btnGeneralFilter = new System.Windows.Forms.Button();
			this.Label3 = new System.Windows.Forms.Label();
			this.TabPage3 = new System.Windows.Forms.TabPage();
			this.rbDsc = new System.Windows.Forms.RadioButton();
			this.btnSort = new System.Windows.Forms.Button();
			this.rbAsc = new System.Windows.Forms.RadioButton();
			this.Label2 = new System.Windows.Forms.Label();
			this.cmbSortArg = new System.Windows.Forms.ComboBox();
			this.DataGrid = new System.Windows.Forms.DataGrid();
			this.btnQuery = new System.Windows.Forms.Button();
			this.TabControl1.SuspendLayout();
			this.TabPage1.SuspendLayout();
			this.TabPage4.SuspendLayout();
			this.TabPage2.SuspendLayout();
			this.TabPage3.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.DataGrid)).BeginInit();
			this.SuspendLayout();
			// 
			// TabControl1
			// 
			this.TabControl1.Controls.Add(this.TabPage1);
			this.TabControl1.Controls.Add(this.TabPage4);
			this.TabControl1.Controls.Add(this.TabPage2);
			this.TabControl1.Controls.Add(this.TabPage3);
			this.TabControl1.Location = new System.Drawing.Point(8, 8);
			this.TabControl1.Name = "TabControl1";
			this.TabControl1.SelectedIndex = 0;
			this.TabControl1.Size = new System.Drawing.Size(432, 120);
			this.TabControl1.TabIndex = 17;
			// 
			// TabPage1
			// 
			this.TabPage1.Controls.Add(this.txtFilter);
			this.TabPage1.Controls.Add(this.btnFilterTitle);
			this.TabPage1.Controls.Add(this.Label1);
			this.TabPage1.Location = new System.Drawing.Point(4, 22);
			this.TabPage1.Name = "TabPage1";
			this.TabPage1.Size = new System.Drawing.Size(424, 94);
			this.TabPage1.TabIndex = 0;
			this.TabPage1.Text = "Filter on Customer";
			// 
			// txtFilter
			// 
			this.txtFilter.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.txtFilter.Location = new System.Drawing.Point(72, 24);
			this.txtFilter.Name = "txtFilter";
			this.txtFilter.Size = new System.Drawing.Size(320, 22);
			this.txtFilter.TabIndex = 1;
			this.txtFilter.Text = "ALFKI";
			// 
			// btnFilterTitle
			// 
			this.btnFilterTitle.Location = new System.Drawing.Point(168, 56);
			this.btnFilterTitle.Name = "btnFilterTitle";
			this.btnFilterTitle.Size = new System.Drawing.Size(96, 24);
			this.btnFilterTitle.TabIndex = 2;
			this.btnFilterTitle.Text = "Filter Customer";
			this.btnFilterTitle.Click += new System.EventHandler(this.btnFilterTitle_Click);
			// 
			// Label1
			// 
			this.Label1.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.Label1.Location = new System.Drawing.Point(16, 27);
			this.Label1.Name = "Label1";
			this.Label1.Size = new System.Drawing.Size(56, 16);
			this.Label1.TabIndex = 7;
			this.Label1.Text = "Customer";
			this.Label1.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// TabPage4
			// 
			this.TabPage4.Controls.Add(this.label5);
			this.TabPage4.Controls.Add(this.cmbFields);
			this.TabPage4.Controls.Add(this.txtFilterColumn);
			this.TabPage4.Controls.Add(this.btnFilteronColumn);
			this.TabPage4.Controls.Add(this.Label4);
			this.TabPage4.Location = new System.Drawing.Point(4, 22);
			this.TabPage4.Name = "TabPage4";
			this.TabPage4.Size = new System.Drawing.Size(424, 94);
			this.TabPage4.TabIndex = 3;
			this.TabPage4.Text = "Filter on Column";
			this.TabPage4.Visible = false;
			// 
			// label5
			// 
			this.label5.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.label5.Location = new System.Drawing.Point(176, 8);
			this.label5.Name = "label5";
			this.label5.Size = new System.Drawing.Size(112, 16);
			this.label5.TabIndex = 9;
			this.label5.Text = "Filter Expression";
			this.label5.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// cmbFields
			// 
			this.cmbFields.DropDownWidth = 144;
			this.cmbFields.Location = new System.Drawing.Point(16, 25);
			this.cmbFields.Name = "cmbFields";
			this.cmbFields.Size = new System.Drawing.Size(144, 21);
			this.cmbFields.TabIndex = 8;
			this.cmbFields.Text = "OrderID";
			// 
			// txtFilterColumn
			// 
			this.txtFilterColumn.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.txtFilterColumn.Location = new System.Drawing.Point(176, 24);
			this.txtFilterColumn.Name = "txtFilterColumn";
			this.txtFilterColumn.Size = new System.Drawing.Size(232, 22);
			this.txtFilterColumn.TabIndex = 1;
			this.txtFilterColumn.Text = "= 10248";
			// 
			// btnFilteronColumn
			// 
			this.btnFilteronColumn.Location = new System.Drawing.Point(128, 62);
			this.btnFilteronColumn.Name = "btnFilteronColumn";
			this.btnFilteronColumn.Size = new System.Drawing.Size(186, 24);
			this.btnFilteronColumn.TabIndex = 2;
			this.btnFilteronColumn.Text = "Filter on Column / Expression";
			this.btnFilteronColumn.Click += new System.EventHandler(this.btnFilteronColumn_Click);
			// 
			// Label4
			// 
			this.Label4.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.Label4.Location = new System.Drawing.Point(13, 8);
			this.Label4.Name = "Label4";
			this.Label4.Size = new System.Drawing.Size(48, 16);
			this.Label4.TabIndex = 7;
			this.Label4.Text = "Column";
			this.Label4.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// TabPage2
			// 
			this.TabPage2.Controls.Add(this.txtGeneralFilter);
			this.TabPage2.Controls.Add(this.btnGeneralFilter);
			this.TabPage2.Controls.Add(this.Label3);
			this.TabPage2.Location = new System.Drawing.Point(4, 22);
			this.TabPage2.Name = "TabPage2";
			this.TabPage2.Size = new System.Drawing.Size(424, 94);
			this.TabPage2.TabIndex = 1;
			this.TabPage2.Text = "General Filter";
			this.TabPage2.Visible = false;
			// 
			// txtGeneralFilter
			// 
			this.txtGeneralFilter.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.txtGeneralFilter.Location = new System.Drawing.Point(89, 24);
			this.txtGeneralFilter.Name = "txtGeneralFilter";
			this.txtGeneralFilter.Size = new System.Drawing.Size(264, 22);
			this.txtGeneralFilter.TabIndex = 1;
			this.txtGeneralFilter.Text = "CustomerID = \'ANATR\'";
			// 
			// btnGeneralFilter
			// 
			this.btnGeneralFilter.Location = new System.Drawing.Point(176, 57);
			this.btnGeneralFilter.Name = "btnGeneralFilter";
			this.btnGeneralFilter.Size = new System.Drawing.Size(96, 24);
			this.btnGeneralFilter.TabIndex = 2;
			this.btnGeneralFilter.Text = "Filter";
			this.btnGeneralFilter.Click += new System.EventHandler(this.btnGeneralFilter_Click);
			// 
			// Label3
			// 
			this.Label3.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.Label3.Location = new System.Drawing.Point(16, 29);
			this.Label3.Name = "Label3";
			this.Label3.Size = new System.Drawing.Size(72, 16);
			this.Label3.TabIndex = 7;
			this.Label3.Text = "Filter criteria";
			this.Label3.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// TabPage3
			// 
			this.TabPage3.Controls.Add(this.rbDsc);
			this.TabPage3.Controls.Add(this.btnSort);
			this.TabPage3.Controls.Add(this.rbAsc);
			this.TabPage3.Controls.Add(this.Label2);
			this.TabPage3.Controls.Add(this.cmbSortArg);
			this.TabPage3.Location = new System.Drawing.Point(4, 22);
			this.TabPage3.Name = "TabPage3";
			this.TabPage3.Size = new System.Drawing.Size(424, 94);
			this.TabPage3.TabIndex = 2;
			this.TabPage3.Text = "Sort";
			this.TabPage3.Visible = false;
			// 
			// rbDsc
			// 
			this.rbDsc.Location = new System.Drawing.Point(316, 37);
			this.rbDsc.Name = "rbDsc";
			this.rbDsc.Size = new System.Drawing.Size(88, 16);
			this.rbDsc.TabIndex = 8;
			this.rbDsc.Text = "Descending";
			// 
			// btnSort
			// 
			this.btnSort.Location = new System.Drawing.Point(192, 56);
			this.btnSort.Name = "btnSort";
			this.btnSort.Size = new System.Drawing.Size(96, 24);
			this.btnSort.TabIndex = 2;
			this.btnSort.Text = "Sort";
			this.btnSort.Click += new System.EventHandler(this.btnSort_Click);
			// 
			// rbAsc
			// 
			this.rbAsc.Checked = true;
			this.rbAsc.Location = new System.Drawing.Point(316, 21);
			this.rbAsc.Name = "rbAsc";
			this.rbAsc.Size = new System.Drawing.Size(80, 16);
			this.rbAsc.TabIndex = 8;
			this.rbAsc.TabStop = true;
			this.rbAsc.Text = "Ascending";
			// 
			// Label2
			// 
			this.Label2.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.Label2.Location = new System.Drawing.Point(8, 24);
			this.Label2.Name = "Label2";
			this.Label2.Size = new System.Drawing.Size(64, 24);
			this.Label2.TabIndex = 7;
			this.Label2.Text = "Sort by...";
			this.Label2.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// cmbSortArg
			// 
			this.cmbSortArg.DropDownWidth = 176;
			this.cmbSortArg.Location = new System.Drawing.Point(80, 24);
			this.cmbSortArg.Name = "cmbSortArg";
			this.cmbSortArg.Size = new System.Drawing.Size(216, 21);
			this.cmbSortArg.TabIndex = 9;
			// 
			// DataGrid
			// 
			this.DataGrid.AlternatingBackColor = System.Drawing.Color.LightGray;
			this.DataGrid.BackColor = System.Drawing.Color.DarkGray;
			this.DataGrid.CaptionBackColor = System.Drawing.Color.White;
			this.DataGrid.CaptionFont = new System.Drawing.Font("Verdana", 10F);
			this.DataGrid.CaptionForeColor = System.Drawing.Color.Navy;
			this.DataGrid.CaptionText = "Orders from Northwind";
			this.DataGrid.DataMember = "";
			this.DataGrid.Dock = System.Windows.Forms.DockStyle.Bottom;
			this.DataGrid.ForeColor = System.Drawing.Color.Black;
			this.DataGrid.GridLineColor = System.Drawing.Color.Black;
			this.DataGrid.GridLineStyle = System.Windows.Forms.DataGridLineStyle.None;
			this.DataGrid.HeaderBackColor = System.Drawing.Color.Silver;
			this.DataGrid.HeaderForeColor = System.Drawing.Color.Black;
			this.DataGrid.LinkColor = System.Drawing.Color.Navy;
			this.DataGrid.Location = new System.Drawing.Point(0, 141);
			this.DataGrid.Name = "DataGrid";
			this.DataGrid.ParentRowsBackColor = System.Drawing.Color.White;
			this.DataGrid.ParentRowsForeColor = System.Drawing.Color.Black;
			this.DataGrid.SelectionBackColor = System.Drawing.Color.Navy;
			this.DataGrid.SelectionForeColor = System.Drawing.Color.White;
			this.DataGrid.Size = new System.Drawing.Size(536, 344);
			this.DataGrid.TabIndex = 16;
			// 
			// btnQuery
			// 
			this.btnQuery.Location = new System.Drawing.Point(456, 64);
			this.btnQuery.Name = "btnQuery";
			this.btnQuery.Size = new System.Drawing.Size(72, 24);
			this.btnQuery.TabIndex = 13;
			this.btnQuery.Text = "Refresh";
			this.btnQuery.Click += new System.EventHandler(this.btnQuery_Click);
			// 
			// FilterOrder
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(536, 485);
			this.Controls.Add(this.TabControl1);
			this.Controls.Add(this.DataGrid);
			this.Controls.Add(this.btnQuery);
			this.Name = "FilterOrder";
			this.Text = "Filtering and Sorting with the DataView";
			this.TabControl1.ResumeLayout(false);
			this.TabPage1.ResumeLayout(false);
			this.TabPage4.ResumeLayout(false);
			this.TabPage2.ResumeLayout(false);
			this.TabPage3.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.DataGrid)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		[STAThread]
		static void Main() 
		{
			Application.Run(new FilterOrder());
		}
	}
}
