using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Data.SqlClient;

namespace WithDataViewManager
{
	public class MyDataViewManager : System.Windows.Forms.Form
	{
		private System.Windows.Forms.DataGrid dataGrid;
		private System.ComponentModel.Container components = null;

		public MyDataViewManager()
		{
			InitializeComponent();

			// Create a Connection, DataAdapters, and a DataSet.
			SqlConnection nwindConn = new SqlConnection(
				"server=xeon;database=northwind;uid=sa;pwd=manager");

			SqlDataAdapter custDA = new SqlDataAdapter(
				"SELECT * FROM Customers", nwindConn);
			SqlDataAdapter orderDA = new SqlDataAdapter(
				"SELECT * FROM Orders", nwindConn);
			SqlDataAdapter ordDetDA = new SqlDataAdapter(
				"SELECT * FROM [Order Details]", nwindConn);

			DataSet custDS = new DataSet();

			// Fill the DataSet with schema information and data.
			custDA.MissingSchemaAction = MissingSchemaAction.AddWithKey;
			orderDA.MissingSchemaAction = MissingSchemaAction.AddWithKey;
			ordDetDA.MissingSchemaAction = MissingSchemaAction.AddWithKey;

			custDA.Fill(custDS, "Customers");
			orderDA.Fill(custDS, "Orders");
			ordDetDA.Fill(custDS, "OrderDetails");

			// Create Relationships.
			custDS.Relations.Add("CustomerOrders",
				custDS.Tables["Customers"].Columns["CustomerID"],
				custDS.Tables["Orders"].Columns["CustomerID"]);

			custDS.Relations.Add("OrderDetails",
				custDS.Tables["Orders"].Columns["OrderID"],
				custDS.Tables["OrderDetails"].Columns["OrderID"]);

			// Create DataView settings for each Table
			// using the DataViewManager
			DataViewManager myDVM = new DataViewManager(custDS);

			// Loop through the DataViewSettings and set Sort
			// or Rowfilter for each Table individually
			String myTable;
			foreach (DataViewSetting myDVS in myDVM.DataViewSettings) 
			{
				// Set Default Sort Order = Primary Key for all Tables
				myDVS.ApplyDefaultSort = true;

				// Set individual Sort and Rowfilter ...
				myTable = myDVS.Table.ToString();
				if (myTable == "Customers") 
				{
					myDVS.Sort = "CompanyName DESC";
				}
				if (myTable == "Orders") 
				{
					myDVS.RowFilter = "OrderDate >= '01.03.1998' AND OrderDate <= '31.03.1998'";
				}
				if (myTable == "OrderDetails") 
				{
					myDVS.RowFilter = "ProductID = 35";
				}
			}

			// ... or directly (the same as above)
			myDVM.DataViewSettings["Customers"].Sort = "CompanyName DESC";
			myDVM.DataViewSettings["Orders"].RowFilter = "OrderDate >= '01.03.1998' AND OrderDate <= '31.03.1998'";
			myDVM.DataViewSettings["OrderDetails"].RowFilter = "ProductID = 35";

			// Bind the DataViewManager to a DataGrid
			dataGrid.SetDataBinding(myDVM, "Customers");
		}
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.dataGrid = new System.Windows.Forms.DataGrid();
			((System.ComponentModel.ISupportInitialize)(this.dataGrid)).BeginInit();
			this.SuspendLayout();
			// 
			// dataGrid
			// 
			this.dataGrid.DataMember = "";
			this.dataGrid.HeaderForeColor = System.Drawing.SystemColors.ControlText;
			this.dataGrid.Location = new System.Drawing.Point(8, 16);
			this.dataGrid.Name = "dataGrid";
			this.dataGrid.Size = new System.Drawing.Size(568, 264);
			this.dataGrid.TabIndex = 0;
			// 
			// MyDataViewManager
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(584, 293);
			this.Controls.Add(this.dataGrid);
			this.Name = "MyDataViewManager";
			this.Text = "Apply Sort and Filter using a DataViewManger";
			((System.ComponentModel.ISupportInitialize)(this.dataGrid)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		[STAThread]
		static void Main() 
		{
			Application.Run(new MyDataViewManager());
		}
	}
}
